import { Component, Input, OnInit } from '@angular/core';

import { Observable, Subscription, of } from 'rxjs';
import { catchError, exhaustMap, map, tap, take } from 'rxjs/operators';


import { ProbeService } from '../service/probe.service';
import { Interface } from '@overflow/model/net/nic';


export interface Address {
  label: string;
  value: string;
}

@Component({
  selector: 'app-nic-dropdown',
  templateUrl: './nic-dropdown.component.html',
  styleUrls: ['./nic-dropdown.component.scss'],
})
export class NicDropdownComponent implements OnInit {
  @Input() blockTarget: any;

  addresses: Address[];
  selectedAddress: Address;

  constructor(
    private probeService: ProbeService,
  ) {

  }

  ngOnInit(): void {
    this.probeService.call<Interface>('MachineService.Interfaces').pipe(
      map((ifaces: Interface[]) => {
        console.log(ifaces);
        this.addresses = [];
        ifaces.forEach(iface => {
          iface.addresses.forEach(address => {
            this.addresses.push({
              label: address.address,
              value: address.address,
            });
          });
        });
      }),
      catchError(error => {
        console.log(error);
        return of();
      }),
      take(1),
    ).subscribe();
  }
}
